Creates a configuration object for computing Mahalanobis dissimilarity.
Pass the result to dissimilarity() to compute the dissimilarity
matrix.
The Mahalanobis distance is computed by first transforming the data into
Mahalanobis space via a factorization of the inverse covariance matrix
M^-1 = W^TWM^-1 = W'W (using SVD), then applying Euclidean distance in
that transformed space:
d(x_i, x_j) = 1p(x_i - x_j)M^-1(x_i - x_j)^Td(x_i, x_j) = sqrt(1/p * (x_i - x_j) M^-1 (x_i - x_j)^T)