Skip to contents

Maturing lifecycle

Functions for dissimilarity assessment, nearest-neighbour search, memory-based learning, local expert libraries, and evolutionary training subset search in spectral chemometrics.

Details

This is the version 3.0.1 – tarragona of the package. It implements a number of functions useful for modeling complex spectral spectra (e.g. NIR, IR). The package includes functions for dimensionality reduction, computing spectral dissimilarity matrices, nearest neighbor search, and modeling spectral data using memory-based learning and evolutionary search of optimal training subsets in large and complex datasets. This package builds upon the methods presented in Ramirez-Lopez et al. (2013a) doi:10.1016/j.geoderma.2012.12.014 , Ramirez-Lopez et al. (2026a) and Ramirez-Lopez et al. (2026b).

Development versions can be found in the github repository of the package at https://github.com/l-ramirez-lopez/resemble.

The functions available for computing dissimilarity matrices are:

  • dissimilarity: Computes a dissimilarity matrix based on a specified method.

  • diss_pca: constructor for principal components-based dissimilarity method.

  • diss_pls: constructor for partial least squares-based dissimilarity method.

  • diss_correlation: constructor for correlation-based dissimilarity method.

  • diss_euclidean: constructor for euclidean distance-based dissimilarity method.

  • diss_mahalanobis: constructor for Mahalanobis distance-based dissimilarity method.

  • diss_cosine: constructor for cosine-based dissimilarity method.

The functions available for evaluating dissimilarity matrices are:

  • diss_evaluate: Evaluates the effectiveness of a dissimilarity matrix using side information.

The functions available for nearest neighbor search:

  • search_neighbors: Search for nearest neighbors of a query spectrum in a reference dataset based on a specified dissimilarity method.

The functions available for modeling spectral data:

  • mbl: Memory-based learning for modeling spectral data.

  • gesearch: An evolutionary method to search optimal samples in large spectral datasets.

  • liblex: Builds a library of reusable localized models.

The functions available for dimensionality reduction are:

References

Ramirez-Lopez, L., Viscarra Rossel, R., Behrens, T., Orellano, C., Perez-Fernandez, E., Kooijman, L., Wadoux, A. M. J.-C., Breure, T., Summerauer, L., Safanelli, J. L., & Plans, M. (2026a). When spectral libraries are too complex to search: Evolutionary subset selection for domain-adaptive calibration. Analytica Chimica Acta, under review.

Ramirez-Lopez, L., Metz, M., Lesnoff, M., Orellano, C., Perez-Fernandez, E., Plans, M., Breure, T., Behrens, T., Viscarra Rossel, R., & Peng, Y. (2026b). Rethinking local spectral modelling: From per-query refitting to model libraries. Analytica Chimica Acta, under review.

Ramirez-Lopez, L., Behrens, T., Schmidt, K., Stevens, A., Dematte, J.A.M., Scholten, T. (2013a). The spectrum-based learner: A new local approach for modeling soil vis-NIR spectra of complex data sets. Geoderma 195-196, 268-279.

Author

Maintainer / Creator: Leonardo Ramirez-Lopez ramirez.lopez.leo@gmail.com

Authors:

  • Leonardo Ramirez-Lopez (ORCID)

  • Antoine Stevens (ORCID)

  • Claudio Orellano